@@ -1,6 +1,6 @@
 import { isNumber } from 'lodash';
 
-import { dateTime, isDateTimeInput } from '../datetime';
+import { isDateTimeInput, dateTime } from '../datetime/moment_wrapper';
 import { Field, FieldType } from '../types/dataFrame';
 
 type IndexComparer = (a: number, b: number) => number;
