@@ -1,6 +1,8 @@
 import { Observable } from 'rxjs';
 
-import { DataQuery } from '@grafana/schema';
+import { DataQuery, LogsSortOrder } from '@grafana/schema';
+
+import { BusEventWithPayload } from '../events/types';
 
 import { KeyValue, Labels } from './data';
 import { DataFrame } from './dataFrame';
@@ -33,6 +35,21 @@ export enum LogLevel {
   unknown = 'unknown',
 }
 
+/**
+ * Mapping of log level abbreviation to canonical log level.
+ * Supported levels are reduce to limit color variation.
+ */
+export const NumericLogLevel: Record<string, LogLevel> = {
+  '0': LogLevel.critical,
+  '1': LogLevel.critical,
+  '2': LogLevel.critical,
+  '3': LogLevel.error,
+  '4': LogLevel.warning,
+  '5': LogLevel.info,
+  '6': LogLevel.info,
+  '7': LogLevel.debug,
+};
+
 // Used for meta information such as common labels or returned log rows in logs view in Explore
 export enum LogsMetaKind {
   Number,
@@ -55,7 +72,7 @@ export interface LogRowModel {
   // the same as rows final index when rendered.
   rowIndex: number;
 
-  // The value of the the dataframe's id field, if it exists
+  // The value of the dataframe's id field, if it exists
   rowId?: string;
 
   // Full DataFrame from which we parsed this log.
@@ -220,7 +237,6 @@ export type LogsVolumeCustomMetaData = {
  * Data sources that support supplementary queries in Explore.
  * This will enable users to see additional data when running original queries.
  * Supported supplementary queries are defined in SupplementaryQueryType enum.
- * @internal
  */
 export interface DataSourceWithSupplementaryQueriesSupport<TQuery extends DataQuery> {
   /**
@@ -352,3 +368,11 @@ export const hasQueryModificationSupport = <TQuery extends DataQuery>(
     'getSupportedQueryModifications' in datasource
   );
 };
+
+export interface LogSortOrderChangePayload {
+  order: LogsSortOrder;
+}
+
+export class LogSortOrderChangeEvent extends BusEventWithPayload<LogSortOrderChangePayload> {
+  static type = 'logs-sort-order-change';
+}
