@@ -1,5 +1,3 @@
-import React from 'react';
-
 import { Field, LinkModel } from '@grafana/data';
 
 import { ButtonProps, Button } from '../Button';
@@ -30,7 +28,7 @@ export function DataLinkButton({ link, buttonProps }: DataLinkButtonProps) {
       }
     >
       <Button
-        icon={link.target === '_blank' ? 'external-link-alt' : undefined}
+        icon={link.target === '_blank' ? 'external-link-alt' : 'link'}
         variant="primary"
         size="sm"
         {...buttonProps}
