@@ -2,9 +2,7 @@ import { css } from '@emotion/css';
 
 import { GrafanaTheme2 } from '@grafana/data';
 
-import { stylesFactory } from '../../themes';
-
-export const getModalStyles = stylesFactory((theme: GrafanaTheme2) => {
+export const getModalStyles = (theme: GrafanaTheme2) => {
   const borderRadius = theme.shape.radius.default;
 
   return {
@@ -80,4 +78,4 @@ export const getModalStyles = stylesFactory((theme: GrafanaTheme2) => {
       paddingTop: theme.spacing(3),
     }),
   };
-});
+};
