@@ -1,5 +1,4 @@
-import { Meta, Story } from '@storybook/react';
-import React from 'react';
+import { Meta, StoryFn } from '@storybook/react';
 
 import { Spinner } from '@grafana/ui';
 
@@ -29,7 +28,7 @@ interface StoryProps extends Partial<Props> {
   withStyle: boolean;
 }
 
-export const Basic: Story<StoryProps> = (args) => {
+export const Basic: StoryFn<StoryProps> = (args) => {
   return (
     <div>
       <Spinner
