@@ -405,6 +405,8 @@ const (
 	TypeVariantSet
 	// TypeNoData is a no data response without a known data type.
 	TypeNoData
+	// TypeTableData is a tabular data response.
+	TypeTableData
 )
 
 // String returns a string representation of the ReturnType.
@@ -422,6 +424,8 @@ func (f ReturnType) String() string {
 		return "variant"
 	case TypeNoData:
 		return "noData"
+	case TypeTableData:
+		return "tableData"
 	default:
 		return "unknown"
 	}
