@@ -3,6 +3,7 @@ package dashboards
 import (
 	"errors"
 
+	"github.com/grafana/grafana/pkg/apimachinery/errutil"
 	"github.com/grafana/grafana/pkg/util"
 )
 
@@ -31,11 +32,6 @@ var (
 		Reason:     "A dashboard with the same uid already exists",
 		StatusCode: 400,
 	}
-	ErrDashboardWithSameNameInFolderExists = DashboardErr{
-		Reason:     "A dashboard with the same name in the folder already exists",
-		StatusCode: 412,
-		Status:     "name-exists",
-	}
 	ErrDashboardVersionMismatch = DashboardErr{
 		Reason:     "The dashboard has been changed by someone else",
 		StatusCode: 412,
@@ -46,6 +42,11 @@ var (
 		StatusCode: 400,
 		Status:     "empty-name",
 	}
+	ErrDashboardTitleTooLong = DashboardErr{
+		Reason:     "Dashboard title cannot contain more than 5 000 characters",
+		StatusCode: 400,
+		Status:     "title-too-long",
+	}
 	ErrDashboardFolderCannotHaveParent = DashboardErr{
 		Reason:     "A Dashboard Folder cannot be added to another folder",
 		StatusCode: 400,
@@ -58,15 +59,6 @@ var (
 		Reason:     "Dashboard cannot be changed to a folder",
 		StatusCode: 400,
 	}
-	ErrDashboardFolderWithSameNameAsDashboard = DashboardErr{
-		Reason:     "Folder name cannot be the same as one of its dashboards",
-		StatusCode: 400,
-	}
-	ErrDashboardWithSameNameAsFolder = DashboardErr{
-		Reason:     "Dashboard name cannot be the same as folder",
-		StatusCode: 400,
-		Status:     "name-match",
-	}
 	ErrDashboardFolderNameExists = DashboardErr{
 		Reason:     "A folder with that name already exists",
 		StatusCode: 400,
@@ -116,14 +108,22 @@ var (
 		StatusCode: 404,
 		Status:     "not-found",
 	}
+	ErrFolderRestoreNotFound = DashboardErr{
+		Reason:     "Restoring folder not found",
+		StatusCode: 400,
+		Status:     "bad-request",
+	}
 
-	ErrFolderNotFound          = errors.New("folder not found")
-	ErrFolderVersionMismatch   = errors.New("the folder has been changed by someone else")
-	ErrFolderTitleEmpty        = errors.New("folder title cannot be empty")
-	ErrFolderWithSameUIDExists = errors.New("a folder/dashboard with the same uid already exists")
-	ErrFolderInvalidUID        = errors.New("invalid uid for folder provided")
-	ErrFolderSameNameExists    = errors.New("a folder with the same name already exists in the current location")
-	ErrFolderAccessDenied      = errors.New("access denied to folder")
+	ErrFolderNotFound             = errors.New("folder not found")
+	ErrFolderVersionMismatch      = errors.New("the folder has been changed by someone else")
+	ErrFolderTitleEmpty           = errors.New("folder title cannot be empty")
+	ErrFolderWithSameUIDExists    = errors.New("a folder/dashboard with the same uid already exists")
+	ErrFolderInvalidUID           = errors.New("invalid uid for folder provided")
+	ErrFolderAccessDenied         = errors.New("access denied to folder")
+	ErrUserIsNotSignedInToOrg     = errors.New("user is not signed in to organization")
+	ErrMoveAccessDenied           = errutil.Forbidden("folders.forbiddenMove", errutil.WithPublicMessage("Access denied to the destination folder"))
+	ErrFolderAccessEscalation     = errutil.Forbidden("folders.accessEscalation", errutil.WithPublicMessage("Cannot move a folder to a folder where you have higher permissions"))
+	ErrFolderCreationAccessDenied = errutil.Forbidden("folders.forbiddenCreation", errutil.WithPublicMessage("not enough permissions to create a folder in the selected location"))
 )
 
 // DashboardErr represents a dashboard error.
