@@ -38,7 +38,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all panel elements and both panels and variables exist, it should only return panels",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreateVariableCommand(sc.folder.ID, "query0")
+			// nolint:staticcheck
+			command := getCreateVariableCommand(sc.folder.ID, sc.folder.UID, "query0")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -62,7 +63,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          1,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -104,7 +106,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all variable elements and both panels and variables exist, it should only return panels",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreateVariableCommand(sc.folder.ID, "query0")
+			// nolint:staticcheck
+			command := getCreateVariableCommand(sc.folder.ID, sc.folder.UID, "query0")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -128,7 +131,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "query0",
 							Kind:        int64(model.VariableElement),
@@ -169,7 +173,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist, it should succeed",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -189,7 +194,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          1,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -224,7 +230,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[1].UID,
 							Name:        "Text - Library Panel2",
 							Kind:        int64(model.PanelElement),
@@ -266,7 +273,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and sort desc is set, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -289,7 +297,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel2",
 							Kind:        int64(model.PanelElement),
@@ -324,7 +333,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          1,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[1].UID,
 							Name:        "Text - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -366,7 +376,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and typeFilter is set to existing types, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreateCommandWithModel(sc.folder.ID, "Gauge - Library Panel", model.PanelElement, []byte(`
+			// nolint:staticcheck
+			command := getCreateCommandWithModel(sc.folder.ID, sc.folder.UID, "Gauge - Library Panel", model.PanelElement, []byte(`
 			{
 			  "datasource": "${DS_GDEV-TESTDATA}",
 			  "id": 1,
@@ -379,7 +390,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
 
-			command = getCreateCommandWithModel(sc.folder.ID, "BarGauge - Library Panel", model.PanelElement, []byte(`
+			// nolint:staticcheck
+			command = getCreateCommandWithModel(sc.folder.ID, sc.folder.UID, "BarGauge - Library Panel", model.PanelElement, []byte(`
 			{
 			  "datasource": "${DS_GDEV-TESTDATA}",
 			  "id": 1,
@@ -410,7 +422,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          3,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "BarGauge - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -445,7 +458,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[1].UID,
 							Name:        "Gauge - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -487,7 +501,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and typeFilter is set to a nonexistent type, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreateCommandWithModel(sc.folder.ID, "Gauge - Library Panel", model.PanelElement, []byte(`
+			// nolint:staticcheck
+			command := getCreateCommandWithModel(sc.folder.ID, sc.folder.UID, "Gauge - Library Panel", model.PanelElement, []byte(`
 			{
 			  "datasource": "${DS_GDEV-TESTDATA}",
 			  "id": 1,
@@ -522,23 +537,24 @@ func TestGetAllLibraryElements(t *testing.T) {
 			}
 		})
 
-	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and folderFilter is set to existing folders, it should succeed and the result should be correct",
+	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and folderFilterUIDs is set to existing folders, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
 			newFolder := createFolder(t, sc, "NewFolder")
-			command := getCreatePanelCommand(newFolder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(newFolder.ID, newFolder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
-			folderFilter := strconv.FormatInt(newFolder.ID, 10)
-
+			folderFilterUID := newFolder.UID
 			err := sc.reqContext.Req.ParseForm()
 			require.NoError(t, err)
-			sc.reqContext.Req.Form.Add("folderFilter", folderFilter)
+			sc.reqContext.Req.Form.Add("folderFilterUIDs", folderFilterUID)
 			resp = sc.service.getAllHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
 
 			var result libraryElementsSearch
 			err = json.Unmarshal(resp.Body(), &result)
+
 			require.NoError(t, err)
 			var expected = libraryElementsSearch{
 				Result: libraryElementsSearchResult{
@@ -549,7 +565,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    newFolder.ID,
+							FolderID:    newFolder.ID, // nolint:staticcheck
+							FolderUID:   newFolder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel2",
 							Kind:        int64(model.PanelElement),
@@ -592,15 +609,16 @@ func TestGetAllLibraryElements(t *testing.T) {
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and folderFilter is set to a nonexistent folders, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
 			newFolder := createFolder(t, sc, "NewFolder")
-			command := getCreatePanelCommand(newFolder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(newFolder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
-			folderFilter := "2020,2021"
+			folderFilterUIDs := "2020,2021"
 
 			err := sc.reqContext.Req.ParseForm()
 			require.NoError(t, err)
-			sc.reqContext.Req.Form.Add("folderFilter", folderFilter)
+			sc.reqContext.Req.Form.Add("folderFilterUIDs", folderFilterUIDs)
 			resp = sc.service.getAllHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
 
@@ -622,7 +640,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and folderFilter is set to General folder, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -646,7 +665,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          1,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -681,7 +701,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[1].UID,
 							Name:        "Text - Library Panel2",
 							Kind:        int64(model.PanelElement),
@@ -723,7 +744,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and excludeUID is set, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -746,7 +768,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel2",
 							Kind:        int64(model.PanelElement),
@@ -788,7 +811,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and perPage is 1, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -811,7 +835,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          1,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -853,7 +878,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and perPage is 1 and page is 2, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -877,7 +903,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel2",
 							Kind:        int64(model.PanelElement),
@@ -919,7 +946,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and searchString exists in the description, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreateCommandWithModel(sc.folder.ID, "Text - Library Panel2", model.PanelElement, []byte(`
+			// nolint:staticcheck
+			command := getCreateCommandWithModel(sc.folder.ID, sc.folder.UID, "Text - Library Panel2", model.PanelElement, []byte(`
 			{
 			  "datasource": "${DS_GDEV-TESTDATA}",
 			  "id": 1,
@@ -952,7 +980,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          1,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -994,7 +1023,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and searchString exists in both name and description, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreateCommandWithModel(sc.folder.ID, "Some Other", model.PanelElement, []byte(`
+			// nolint:staticcheck
+			command := getCreateCommandWithModel(sc.folder.ID, sc.folder.UID, "Some Other", model.PanelElement, []byte(`
 			{
 			  "datasource": "${DS_GDEV-TESTDATA}",
 			  "id": 1,
@@ -1025,7 +1055,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Some Other",
 							Kind:        int64(model.PanelElement),
@@ -1060,7 +1091,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          1,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[1].UID,
 							Name:        "Text - Library Panel",
 							Kind:        int64(model.PanelElement),
@@ -1102,7 +1134,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and perPage is 1 and page is 1 and searchString is panel2, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -1127,7 +1160,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 						{
 							ID:          2,
 							OrgID:       1,
-							FolderID:    1,
+							FolderID:    1, // nolint:staticcheck
+							FolderUID:   sc.folder.UID,
 							UID:         result.Result.Elements[0].UID,
 							Name:        "Text - Library Panel2",
 							Kind:        int64(model.PanelElement),
@@ -1169,7 +1203,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and perPage is 1 and page is 3 and searchString is panel, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -1200,7 +1235,8 @@ func TestGetAllLibraryElements(t *testing.T) {
 
 	scenarioWithPanel(t, "When an admin tries to get all library panels and two exist and perPage is 1 and page is 3 and searchString does not exist, it should succeed and the result should be correct",
 		func(t *testing.T, sc scenarioContext) {
-			command := getCreatePanelCommand(sc.folder.ID, "Text - Library Panel2")
+			// nolint:staticcheck
+			command := getCreatePanelCommand(sc.folder.ID, sc.folder.UID, "Text - Library Panel2")
 			sc.reqContext.Req.Body = mockRequestBody(command)
 			resp := sc.service.createHandler(sc.reqContext)
 			require.Equal(t, 200, resp.Status())
@@ -1238,6 +1274,7 @@ func TestGetAllLibraryElements(t *testing.T) {
 			err := json.Unmarshal(resp.Body(), &result)
 			require.NoError(t, err)
 			require.Equal(t, 1, len(result.Result.Elements))
+			// nolint:staticcheck
 			require.Equal(t, int64(1), result.Result.Elements[0].FolderID)
 			require.Equal(t, "Text - Library Panel", result.Result.Elements[0].Name)
 
