@@ -13,24 +13,32 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
+	"github.com/grafana/grafana/pkg/bus"
 	"github.com/grafana/grafana/pkg/expr"
-	"github.com/grafana/grafana/pkg/services/auth/identity"
 	"github.com/grafana/grafana/pkg/services/ngalert/accesscontrol"
 	"github.com/grafana/grafana/pkg/services/ngalert/tests/fakes"
+	"github.com/grafana/grafana/pkg/services/supportbundles/supportbundlestest"
 	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/util"
 
 	"github.com/grafana/grafana/pkg/infra/db"
 	"github.com/grafana/grafana/pkg/infra/log"
+	"github.com/grafana/grafana/pkg/infra/tracing"
+	acmock "github.com/grafana/grafana/pkg/services/accesscontrol/mock"
+	"github.com/grafana/grafana/pkg/services/dashboards"
+	"github.com/grafana/grafana/pkg/services/featuremgmt"
 	"github.com/grafana/grafana/pkg/services/folder"
+	"github.com/grafana/grafana/pkg/services/folder/folderimpl"
 	"github.com/grafana/grafana/pkg/services/folder/foldertest"
 	"github.com/grafana/grafana/pkg/services/ngalert/models"
 	"github.com/grafana/grafana/pkg/services/ngalert/store"
+	"github.com/grafana/grafana/pkg/services/ngalert/testutil"
 	"github.com/grafana/grafana/pkg/setting"
 )
 
 func TestAlertRuleService(t *testing.T) {
-	ruleService := createAlertRuleService(t)
+	ruleService := createAlertRuleService(t, nil)
 	var orgID int64 = 1
 	u := &user.SignedInUser{
 		UserID: 1,
@@ -82,7 +90,7 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("group update should propagate folderUID from group to rules", func(t *testing.T) {
-		ruleService := createAlertRuleService(t)
+		ruleService := createAlertRuleService(t, nil)
 		group := createDummyGroup("namespace-test", orgID)
 		group.Rules[0].NamespaceUID = ""
 
@@ -176,6 +184,74 @@ func TestAlertRuleService(t *testing.T) {
 		require.Equal(t, int64(2), readGroup.Rules[0].Version)
 	})
 
+	t.Run("updating a group should not override its rules editor settings", func(t *testing.T) {
+		namespaceUID := "my-namespace"
+		groupTitle := "test-group-123"
+
+		// create the rule group via the rule store, to persist the editor settings
+		rule := createTestRule(util.GenerateShortUID(), groupTitle, orgID, namespaceUID)
+		ruleMetadata := models.AlertRuleMetadata{
+			EditorSettings: models.EditorSettings{
+				SimplifiedQueryAndExpressionsSection: true,
+			},
+		}
+		rule.Metadata = ruleMetadata
+		r, err := ruleService.ruleStore.InsertAlertRules(context.Background(), []models.AlertRule{rule})
+		require.NoError(t, err)
+		require.Len(t, r, 1)
+
+		// Set the UID for the rule to update it
+		rule.UID = r[0].UID
+		// clear the metadata to check that the existing metadata is not overridden
+		rule.Metadata = models.AlertRuleMetadata{}
+
+		// Now update the rule group with the rule to update its metadata
+		group := models.AlertRuleGroup{
+			Title:     groupTitle,
+			Interval:  60,
+			FolderUID: namespaceUID,
+			Rules:     []models.AlertRule{rule},
+		}
+
+		err = ruleService.ReplaceRuleGroup(context.Background(), u, group, models.ProvenanceAPI)
+		require.NoError(t, err)
+
+		readGroup, err := ruleService.GetRuleGroup(context.Background(), u, namespaceUID, groupTitle)
+		require.NoError(t, err)
+		require.NotEmpty(t, readGroup.Rules)
+		require.Len(t, readGroup.Rules, 1)
+
+		// check that the metadata is still there
+		require.Equal(t, ruleMetadata, readGroup.Rules[0].Metadata)
+	})
+
+	t.Run("updating a rule should not override its editor settings", func(t *testing.T) {
+		rule := createTestRule(util.GenerateShortUID(), "my-group", orgID, "my-folder")
+		ruleMetadata := models.AlertRuleMetadata{
+			EditorSettings: models.EditorSettings{
+				SimplifiedQueryAndExpressionsSection: true,
+			},
+		}
+		rule.Metadata = ruleMetadata
+		r, err := ruleService.ruleStore.InsertAlertRules(context.Background(), []models.AlertRule{rule})
+		require.NoError(t, err)
+		require.Len(t, r, 1)
+
+		// Set the UID for the rule to update it
+		rule.UID = r[0].UID
+		// clear the metadata to check that the existing metadata is not overridden
+		rule.Metadata = models.AlertRuleMetadata{}
+
+		// Update the rule
+		_, err = ruleService.UpdateAlertRule(context.Background(), u, rule, models.ProvenanceAPI)
+		require.NoError(t, err)
+
+		// Read the rule and check that the editor settings are preserved
+		readRule, _, err := ruleService.GetAlertRule(context.Background(), u, rule.UID)
+		require.NoError(t, err)
+		require.Equal(t, ruleMetadata, readRule.Metadata)
+	})
+
 	t.Run("updating a group to temporarily overlap rule names should not throw unique constraint", func(t *testing.T) {
 		var orgID int64 = 1
 		group := models.AlertRuleGroup{
@@ -523,7 +599,7 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("quota met causes create to be rejected", func(t *testing.T) {
-		ruleService := createAlertRuleService(t)
+		ruleService := createAlertRuleService(t, nil)
 		checker := &MockQuotaChecker{}
 		checker.EXPECT().LimitExceeded()
 		ruleService.quotas = checker
@@ -534,7 +610,7 @@ func TestAlertRuleService(t *testing.T) {
 	})
 
 	t.Run("quota met causes group write to be rejected", func(t *testing.T) {
-		ruleService := createAlertRuleService(t)
+		ruleService := createAlertRuleService(t, nil)
 		checker := &MockQuotaChecker{}
 		checker.EXPECT().LimitExceeded()
 		ruleService.quotas = checker
@@ -551,7 +627,8 @@ func TestCreateAlertRule(t *testing.T) {
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey := models.GenerateGroupKey(orgID)
 	groupIntervalSeconds := int64(30)
-	rules := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey), models.WithInterval(time.Duration(groupIntervalSeconds)*time.Second)))
+	gen := models.RuleGen
+	rules := gen.With(gen.WithGroupKey(groupKey), gen.WithIntervalSeconds(groupIntervalSeconds)).GenerateManyRef(3)
 	groupProvenance := models.ProvenanceAPI
 
 	initServiceWithData := func(t *testing.T) (*AlertRuleService, *fakes.RuleStore, *fakes.FakeProvisioningStore, *fakeRuleAccessControlService) {
@@ -567,14 +644,14 @@ func TestCreateAlertRule(t *testing.T) {
 
 	t.Run("when user can write all rules", func(t *testing.T) {
 		t.Run("and a new rule creates a new group", func(t *testing.T) {
-			rule := models.AlertRuleGen(models.WithOrgID(orgID))()
+			rule := gen.With(gen.WithOrgID(orgID)).Generate()
 			service, ruleStore, provenanceStore, ac := initServiceWithData(t)
 
 			ac.CanWriteAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
 				return true, nil
 			}
 
-			actualRule, err := service.CreateAlertRule(context.Background(), u, *rule, models.ProvenanceFile)
+			actualRule, err := service.CreateAlertRule(context.Background(), u, rule, models.ProvenanceFile)
 			require.NoError(t, err)
 
 			require.Len(t, ac.Calls, 1)
@@ -601,14 +678,14 @@ func TestCreateAlertRule(t *testing.T) {
 			})
 		})
 		t.Run("and it adds a rule to a group", func(t *testing.T) {
-			rule := models.AlertRuleGen(models.WithGroupKey(groupKey))()
+			rule := gen.With(gen.WithGroupKey(groupKey)).Generate()
 			service, ruleStore, provenanceStore, ac := initServiceWithData(t)
 
 			ac.CanWriteAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
 				return true, nil
 			}
 
-			actualRule, err := service.CreateAlertRule(context.Background(), u, *rule, models.ProvenanceNone)
+			actualRule, err := service.CreateAlertRule(context.Background(), u, rule, models.ProvenanceNone)
 			require.NoError(t, err)
 
 			require.Len(t, ac.Calls, 1)
@@ -637,7 +714,7 @@ func TestCreateAlertRule(t *testing.T) {
 	})
 	t.Run("when user cannot write all rules", func(t *testing.T) {
 		t.Run("and it creates a new group", func(t *testing.T) {
-			rule := models.AlertRuleGen(models.WithOrgID(orgID))()
+			rule := gen.With(gen.WithOrgID(orgID)).Generate()
 			t.Run("it should authorize the change", func(t *testing.T) {
 				service, ruleStore, provenanceStore, ac := initServiceWithData(t)
 
@@ -654,7 +731,7 @@ func TestCreateAlertRule(t *testing.T) {
 					return nil
 				}
 
-				actualRule, err := service.CreateAlertRule(context.Background(), u, *rule, models.ProvenanceFile)
+				actualRule, err := service.CreateAlertRule(context.Background(), u, rule, models.ProvenanceFile)
 				require.NoError(t, err)
 
 				require.Len(t, ac.Calls, 2)
@@ -683,7 +760,7 @@ func TestCreateAlertRule(t *testing.T) {
 			})
 		})
 		t.Run("and it adds a rule to a group", func(t *testing.T) {
-			rule := models.AlertRuleGen(models.WithGroupKey(groupKey))()
+			rule := gen.With(gen.WithGroupKey(groupKey)).Generate()
 			t.Run("it should authorize the change to whole group", func(t *testing.T) {
 				service, ruleStore, provenanceStore, ac := initServiceWithData(t)
 
@@ -701,7 +778,7 @@ func TestCreateAlertRule(t *testing.T) {
 					return nil
 				}
 
-				actualRule, err := service.CreateAlertRule(context.Background(), u, *rule, models.ProvenanceNone)
+				actualRule, err := service.CreateAlertRule(context.Background(), u, rule, models.ProvenanceNone)
 				require.NoError(t, err)
 
 				require.Len(t, ac.Calls, 2)
@@ -730,7 +807,7 @@ func TestCreateAlertRule(t *testing.T) {
 			})
 		})
 		t.Run("it should not insert if not authorized", func(t *testing.T) {
-			rule := models.AlertRuleGen(models.WithGroupKey(groupKey))()
+			rule := gen.With(gen.WithGroupKey(groupKey)).Generate()
 			service, ruleStore, _, ac := initServiceWithData(t)
 
 			ac.CanWriteAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
@@ -741,7 +818,7 @@ func TestCreateAlertRule(t *testing.T) {
 				return expectedErr
 			}
 
-			_, err := service.CreateAlertRule(context.Background(), u, *rule, models.ProvenanceFile)
+			_, err := service.CreateAlertRule(context.Background(), u, rule, models.ProvenanceFile)
 			require.ErrorIs(t, expectedErr, err)
 
 			require.Len(t, ac.Calls, 2)
@@ -756,7 +833,7 @@ func TestCreateAlertRule(t *testing.T) {
 		})
 	})
 
-	ruleService := createAlertRuleService(t)
+	ruleService := createAlertRuleService(t, nil)
 	t.Run("should return the created id", func(t *testing.T) {
 		rule, err := ruleService.CreateAlertRule(context.Background(), u, dummyRule("test#1", orgID), models.ProvenanceNone)
 		require.NoError(t, err)
@@ -790,6 +867,37 @@ func TestCreateAlertRule(t *testing.T) {
 			require.NoError(t, err)
 		})
 	})
+	t.Run("when dashboard is specified", func(t *testing.T) {
+		t.Run("return no error when both specified", func(t *testing.T) {
+			rule := dummyRule("test#4", orgID)
+			dashboardUid := "oinwerfgiuac"
+			panelId := int64(42)
+			rule.Annotations = map[string]string{
+				models.DashboardUIDAnnotation: dashboardUid,
+				models.PanelIDAnnotation:      strconv.FormatInt(panelId, 10),
+			}
+			rule, err := ruleService.CreateAlertRule(context.Background(), u, rule, models.ProvenanceNone)
+			require.NoError(t, err)
+		})
+		t.Run("return 4xx error when missing dashboard uid", func(t *testing.T) {
+			rule := dummyRule("test#3", orgID)
+			panelId := int64(42)
+			rule.Annotations = map[string]string{
+				models.PanelIDAnnotation: strconv.FormatInt(panelId, 10),
+			}
+			rule, err := ruleService.CreateAlertRule(context.Background(), u, rule, models.ProvenanceNone)
+			require.ErrorIs(t, err, models.ErrAlertRuleFailedValidation)
+		})
+		t.Run("return 4xx error when missing panel id", func(t *testing.T) {
+			rule := dummyRule("test#3", orgID)
+			dashboardUid := "oinwerfgiuac"
+			rule.Annotations = map[string]string{
+				models.DashboardUIDAnnotation: dashboardUid,
+			}
+			rule, err := ruleService.CreateAlertRule(context.Background(), u, rule, models.ProvenanceNone)
+			require.ErrorIs(t, err, models.ErrAlertRuleFailedValidation)
+		})
+	})
 }
 
 func TestUpdateAlertRule(t *testing.T) {
@@ -797,7 +905,8 @@ func TestUpdateAlertRule(t *testing.T) {
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey := models.GenerateGroupKey(orgID)
 	groupIntervalSeconds := int64(30)
-	rules := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey), models.WithInterval(time.Duration(groupIntervalSeconds)*time.Second)))
+	gen := models.RuleGen
+	rules := gen.With(gen.WithGroupKey(groupKey), gen.WithIntervalSeconds(groupIntervalSeconds)).GenerateManyRef(3)
 	groupProvenance := models.ProvenanceAPI
 
 	initServiceWithData := func(t *testing.T) (*AlertRuleService, *fakes.RuleStore, *fakes.FakeProvisioningStore, *fakeRuleAccessControlService) {
@@ -891,6 +1000,30 @@ func TestUpdateAlertRule(t *testing.T) {
 			})
 			require.Empty(t, updates)
 		})
+
+		t.Run("when there are no changes it should be successful", func(t *testing.T) {
+			// For this test we will not change the rule, and we will not use "admin" (CanWriteAllRulesFunc)
+			// permissions. The response of the service should still be successful.
+			service, ruleStore, _, ac := initServiceWithData(t)
+
+			rule := models.CopyRule(rules[0])
+
+			_, err := service.ruleStore.InsertAlertRules(context.Background(), []models.AlertRule{*rule})
+			require.NoError(t, err)
+
+			ac.CanWriteAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
+				return false, nil
+			}
+
+			_, err = service.UpdateAlertRule(context.Background(), u, *rule, groupProvenance)
+			require.NoError(t, err)
+
+			updates := ruleStore.GetRecordedCommands(func(cmd any) (any, bool) {
+				a, ok := cmd.([]models.UpdateRule)
+				return a, ok
+			})
+			require.Empty(t, updates)
+		})
 	})
 }
 
@@ -899,7 +1032,8 @@ func TestDeleteAlertRule(t *testing.T) {
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey := models.GenerateGroupKey(orgID)
 	groupIntervalSeconds := int64(30)
-	rules := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey), models.WithInterval(time.Duration(groupIntervalSeconds)*time.Second)))
+	gen := models.RuleGen
+	rules := gen.With(gen.WithGroupKey(groupKey), gen.WithIntervalSeconds(groupIntervalSeconds)).GenerateManyRef(3)
 	groupProvenance := models.ProvenanceAPI
 
 	initServiceWithData := func(t *testing.T) (*AlertRuleService, *fakes.RuleStore, *fakes.FakeProvisioningStore, *fakeRuleAccessControlService) {
@@ -990,7 +1124,8 @@ func TestGetAlertRule(t *testing.T) {
 	orgID := rand.Int63()
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey := models.GenerateGroupKey(orgID)
-	rules := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey)))
+	gen := models.RuleGen
+	rules := gen.With(gen.WithGroupKey(groupKey)).GenerateManyRef(3)
 	rule := rules[0]
 	expectedProvenance := models.ProvenanceAPI
 
@@ -1004,112 +1139,47 @@ func TestGetAlertRule(t *testing.T) {
 		return service, ruleStore, provenanceStore, ac
 	}
 
-	t.Run("when user cannot read all rules", func(t *testing.T) {
-		t.Run("should authorize access to entire group", func(t *testing.T) {
-			service, _, _, ac := initServiceWithData(t)
+	t.Run("should authorize access to rule", func(t *testing.T) {
+		service, _, _, ac := initServiceWithData(t)
 
-			ac.CanReadAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
-				return false, nil
-			}
-
-			expected := errors.New("test")
-			ac.AuthorizeAccessToRuleGroupFunc = func(ctx context.Context, user identity.Requester, r models.RulesGroup) error {
-				assert.Equal(t, u, user)
-				assert.EqualValues(t, rules, r)
-				return expected
-			}
-
-			_, _, err := service.GetAlertRule(context.Background(), u, rule.UID)
-			require.Error(t, err)
-			require.Equal(t, expected, err)
-
-			assert.Len(t, ac.Calls, 2)
-			assert.Equal(t, "CanReadAllRules", ac.Calls[0].Method)
-			assert.Equal(t, "AuthorizeRuleGroupRead", ac.Calls[1].Method)
-
-			ac.Calls = nil
-			ac.AuthorizeAccessToRuleGroupFunc = func(ctx context.Context, user identity.Requester, rules models.RulesGroup) error {
-				return nil
-			}
-
-			actual, provenance, err := service.GetAlertRule(context.Background(), u, rule.UID)
-			require.NoError(t, err)
-			assert.Equal(t, *rule, actual)
-			assert.Equal(t, expectedProvenance, provenance)
-		})
-
-		t.Run("should return ErrAlertRuleNotFound if rule does not exist", func(t *testing.T) {
-			service, ruleStore, _, ac := initServiceWithData(t)
-			ac.CanReadAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
-				return false, nil
-			}
-
-			_, _, err := service.GetAlertRule(context.Background(), u, "no-rule-uid")
-			require.ErrorIs(t, err, models.ErrAlertRuleNotFound)
-
-			assert.Len(t, ac.Calls, 1)
-			assert.Equal(t, "CanReadAllRules", ac.Calls[0].Method)
-			require.IsType(t, ruleStore.RecordedOps[0], models.GetAlertRulesGroupByRuleUIDQuery{})
-			query := ruleStore.RecordedOps[0].(models.GetAlertRulesGroupByRuleUIDQuery)
-			assert.Equal(t, models.GetAlertRulesGroupByRuleUIDQuery{
-				OrgID: orgID,
-				UID:   "no-rule-uid",
-			}, query)
-		})
-	})
-
-	t.Run("when user can read all rules", func(t *testing.T) {
-		t.Run("should query rule by UID and do not check any permissions", func(t *testing.T) {
-			service, ruleStore, _, ac := initServiceWithData(t)
-			ac.CanReadAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
-				assert.Equal(t, u, user)
-				return true, nil
-			}
-
-			actual, provenance, err := service.GetAlertRule(context.Background(), u, rule.UID)
-			require.NoError(t, err)
-			assert.Equal(t, *rule, actual)
-			assert.Equal(t, expectedProvenance, provenance)
-
-			assert.Len(t, ac.Calls, 1)
-			assert.Equal(t, "CanReadAllRules", ac.Calls[0].Method)
-
-			require.Len(t, ruleStore.RecordedOps, 1)
-			require.IsType(t, ruleStore.RecordedOps[0], models.GetAlertRuleByUIDQuery{})
-			query := ruleStore.RecordedOps[0].(models.GetAlertRuleByUIDQuery)
-			assert.Equal(t, models.GetAlertRuleByUIDQuery{
-				OrgID: rule.OrgID,
-				UID:   rule.UID,
-			}, query)
-		})
-
-		t.Run("should return ErrAlertRuleNotFound if rule does not exist", func(t *testing.T) {
-			service, _, _, ac := initServiceWithData(t)
-			ac.CanReadAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
-				return true, nil
-			}
-
-			_, _, err := service.GetAlertRule(context.Background(), u, "no-rule-uid")
-			require.ErrorIs(t, err, models.ErrAlertRuleNotFound)
-		})
-	})
-
-	t.Run("return error immediately when CanReadAllRules returns error", func(t *testing.T) {
-		service, ruleStore, _, ac := initServiceWithData(t)
-
-		expectedErr := errors.New("test")
-		ac.CanReadAllRulesFunc = func(ctx context.Context, user identity.Requester) (bool, error) {
-			return false, expectedErr
+		expected := errors.New("test")
+		ac.AuthorizeAccessInFolderFunc = func(ctx context.Context, user identity.Requester, namespaced models.Namespaced) error {
+			assert.Equal(t, u, user)
+			assert.EqualValues(t, rule, namespaced)
+			return expected
 		}
 
 		_, _, err := service.GetAlertRule(context.Background(), u, rule.UID)
 		require.Error(t, err)
-		require.Equal(t, expectedErr, err)
+		require.Equal(t, expected, err)
 
 		assert.Len(t, ac.Calls, 1)
-		assert.Equal(t, "CanReadAllRules", ac.Calls[0].Method)
+		assert.Equal(t, "AuthorizeRuleRead", ac.Calls[0].Method)
 
-		assert.Empty(t, ruleStore.RecordedOps)
+		ac.Calls = nil
+		ac.AuthorizeAccessInFolderFunc = func(ctx context.Context, user identity.Requester, namespaced models.Namespaced) error {
+			return nil
+		}
+
+		actual, provenance, err := service.GetAlertRule(context.Background(), u, rule.UID)
+		require.NoError(t, err)
+		assert.Equal(t, *rule, actual)
+		assert.Equal(t, expectedProvenance, provenance)
+	})
+
+	t.Run("should return ErrAlertRuleNotFound if rule does not exist", func(t *testing.T) {
+		service, ruleStore, _, ac := initServiceWithData(t)
+
+		_, _, err := service.GetAlertRule(context.Background(), u, "no-rule-uid")
+		require.ErrorIs(t, err, models.ErrAlertRuleNotFound)
+
+		assert.Len(t, ac.Calls, 0)
+		require.IsType(t, ruleStore.RecordedOps[0], models.GetAlertRuleByUIDQuery{})
+		query := ruleStore.RecordedOps[0].(models.GetAlertRuleByUIDQuery)
+		assert.Equal(t, models.GetAlertRuleByUIDQuery{
+			OrgID: orgID,
+			UID:   "no-rule-uid",
+		}, query)
 	})
 }
 
@@ -1118,7 +1188,8 @@ func TestGetRuleGroup(t *testing.T) {
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey := models.GenerateGroupKey(orgID)
 	intervalSeconds := int64(30)
-	rules := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey), models.WithInterval(time.Duration(intervalSeconds)*time.Second)))
+	gen := models.RuleGen
+	rules := gen.With(gen.WithGroupKey(groupKey), gen.WithIntervalSeconds(intervalSeconds)).GenerateManyRef(3)
 	derefRules := make([]models.AlertRule, 0, len(rules))
 	for _, rule := range rules {
 		derefRules = append(derefRules, *rule)
@@ -1226,9 +1297,10 @@ func TestGetAlertRules(t *testing.T) {
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey1 := models.GenerateGroupKey(orgID)
 	groupKey2 := models.GenerateGroupKey(orgID)
-	rules1 := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey1)))
+	gen := models.RuleGen
+	rules1 := gen.With(gen.WithGroupKey(groupKey1), gen.WithUniqueGroupIndex()).GenerateManyRef(3)
 	models.RulesGroup(rules1).SortByGroupIndex()
-	rules2 := models.GenerateAlertRules(4, models.AlertRuleGen(models.WithGroupKey(groupKey2)))
+	rules2 := gen.With(gen.WithGroupKey(groupKey2), gen.WithUniqueGroupIndex()).GenerateManyRef(4)
 	models.RulesGroup(rules2).SortByGroupIndex()
 	allRules := append(rules1, rules2...)
 	expectedProvenance := models.ProvenanceAPI
@@ -1325,7 +1397,8 @@ func TestReplaceGroup(t *testing.T) {
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey := models.GenerateGroupKey(orgID)
 	groupIntervalSeconds := int64(30)
-	rules := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey), models.WithInterval(time.Duration(groupIntervalSeconds)*time.Second)))
+	gen := models.RuleGen
+	rules := gen.With(gen.WithGroupKey(groupKey), gen.WithIntervalSeconds(groupIntervalSeconds)).GenerateManyRef(3)
 	groupProvenance := models.ProvenanceAPI
 
 	initServiceWithData := func(t *testing.T) (*AlertRuleService, *fakes.RuleStore, *fakes.FakeProvisioningStore, *fakeRuleAccessControlService) {
@@ -1438,7 +1511,8 @@ func TestDeleteRuleGroup(t *testing.T) {
 	u := &user.SignedInUser{OrgID: orgID}
 	groupKey := models.GenerateGroupKey(orgID)
 	groupIntervalSeconds := int64(30)
-	rules := models.GenerateAlertRules(3, models.AlertRuleGen(models.WithGroupKey(groupKey), models.WithInterval(time.Duration(groupIntervalSeconds)*time.Second)))
+	gen := models.RuleGen
+	rules := gen.With(gen.WithGroupKey(groupKey), gen.WithIntervalSeconds(groupIntervalSeconds)).GenerateManyRef(3)
 	groupProvenance := models.ProvenanceAPI
 
 	initServiceWithData := func(t *testing.T) (*AlertRuleService, *fakes.RuleStore, *fakes.FakeProvisioningStore, *fakeRuleAccessControlService) {
@@ -1520,6 +1594,89 @@ func TestDeleteRuleGroup(t *testing.T) {
 	})
 }
 
+func TestProvisiongWithFullpath(t *testing.T) {
+	tracer := tracing.InitializeTracerForTest()
+	inProcBus := bus.ProvideBus(tracer)
+	sqlStore, cfg := db.InitTestDBWithCfg(t)
+	folderStore := folderimpl.ProvideDashboardFolderStore(sqlStore)
+	_, dashboardStore := testutil.SetupDashboardService(t, sqlStore, folderStore, cfg)
+	ac := acmock.New()
+	features := featuremgmt.WithFeatures(featuremgmt.FlagNestedFolders)
+	fStore := folderimpl.ProvideStore(sqlStore)
+	folderService := folderimpl.ProvideService(fStore, ac, inProcBus, dashboardStore, folderStore, sqlStore,
+		features, supportbundlestest.NewFakeBundleService(), cfg, nil, tracing.InitializeTracerForTest())
+
+	ruleService := createAlertRuleService(t, folderService)
+	var orgID int64 = 1
+
+	signedInUser := user.SignedInUser{UserID: 1, OrgID: orgID, Permissions: map[int64]map[string][]string{
+		orgID: {
+			dashboards.ActionFoldersCreate: {dashboards.ScopeFoldersAll},
+			dashboards.ActionFoldersRead:   {dashboards.ScopeFoldersAll},
+			dashboards.ActionFoldersWrite:  {dashboards.ScopeFoldersAll}},
+	}}
+	namespaceUID := "my-namespace"
+	namespaceTitle := namespaceUID
+	rootFolder, err := folderService.Create(context.Background(), &folder.CreateFolderCommand{
+		UID:          namespaceUID,
+		Title:        namespaceTitle,
+		OrgID:        orgID,
+		SignedInUser: &signedInUser,
+	})
+	require.NoError(t, err)
+
+	t.Run("for a rule under a root folder should set the right fullpath", func(t *testing.T) {
+		r, err := ruleService.ruleStore.InsertAlertRules(context.Background(), []models.AlertRule{
+			createTestRule("my-cool-group", "my-cool-group", orgID, namespaceUID),
+		})
+		require.NoError(t, err)
+		require.Len(t, r, 1)
+
+		res, err := ruleService.GetAlertRuleWithFolderFullpath(context.Background(), &signedInUser, r[0].UID)
+		require.NoError(t, err)
+		assert.Equal(t, namespaceTitle, res.FolderFullpath)
+
+		res2, err := ruleService.GetAlertRuleGroupWithFolderFullpath(context.Background(), &signedInUser, namespaceUID, "my-cool-group")
+		require.NoError(t, err)
+		assert.Equal(t, namespaceTitle, res2.FolderFullpath)
+
+		res3, err := ruleService.GetAlertGroupsWithFolderFullpath(context.Background(), &signedInUser, []string{namespaceUID})
+		require.NoError(t, err)
+		assert.Equal(t, namespaceTitle, res3[0].FolderFullpath)
+	})
+
+	t.Run("for a rule under a subfolder should set the right fullpath", func(t *testing.T) {
+		otherNamespaceUID := "my-other-namespace"
+		otherNamespaceTitle := "my-other-namespace containing multiple //"
+		_, err := folderService.Create(context.Background(), &folder.CreateFolderCommand{
+			UID:          otherNamespaceUID,
+			Title:        otherNamespaceTitle,
+			OrgID:        orgID,
+			ParentUID:    rootFolder.UID,
+			SignedInUser: &signedInUser,
+		})
+		require.NoError(t, err)
+
+		r, err := ruleService.ruleStore.InsertAlertRules(context.Background(), []models.AlertRule{
+			createTestRule("my-cool-group-2", "my-cool-group-2", orgID, otherNamespaceUID),
+		})
+		require.NoError(t, err)
+		require.Len(t, r, 1)
+
+		res, err := ruleService.GetAlertRuleWithFolderFullpath(context.Background(), &signedInUser, r[0].UID)
+		require.NoError(t, err)
+		assert.Equal(t, "my-namespace/my-other-namespace containing multiple \\/\\/", res.FolderFullpath)
+
+		res2, err := ruleService.GetAlertRuleGroupWithFolderFullpath(context.Background(), &signedInUser, otherNamespaceUID, "my-cool-group-2")
+		require.NoError(t, err)
+		assert.Equal(t, "my-namespace/my-other-namespace containing multiple \\/\\/", res2.FolderFullpath)
+
+		res3, err := ruleService.GetAlertGroupsWithFolderFullpath(context.Background(), &signedInUser, []string{otherNamespaceUID})
+		require.NoError(t, err)
+		assert.Equal(t, "my-namespace/my-other-namespace containing multiple \\/\\/", res3[0].FolderFullpath)
+	})
+}
+
 func getDeleteQueries(ruleStore *fakes.RuleStore) []fakes.GenericRecordedQuery {
 	generic := ruleStore.GetRecordedCommands(func(cmd any) (any, bool) {
 		a, ok := cmd.(fakes.GenericRecordedQuery)
@@ -1535,13 +1692,9 @@ func getDeleteQueries(ruleStore *fakes.RuleStore) []fakes.GenericRecordedQuery {
 	return result
 }
 
-func createAlertRuleService(t *testing.T) AlertRuleService {
+func createAlertRuleService(t *testing.T, folderService folder.Service) AlertRuleService {
 	t.Helper()
 	sqlStore := db.InitTestDB(t)
-	folderService := foldertest.NewFakeService()
-	folderService.ExpectedFolder = &folder.Folder{
-		UID: "default-namespace",
-	}
 	store := store.DBstore{
 		SQLStore: sqlStore,
 		Cfg: setting.UnifiedAlertingSettings{
@@ -1549,10 +1702,16 @@ func createAlertRuleService(t *testing.T) AlertRuleService {
 		},
 		Logger:        log.NewNopLogger(),
 		FolderService: folderService,
+		Bus:           bus.ProvideBus(tracing.InitializeTracerForTest()),
 	}
 	// store := fakes.NewRuleStore(t)
 	quotas := MockQuotaChecker{}
 	quotas.EXPECT().LimitOK()
+
+	if folderService == nil {
+		folderService = foldertest.NewFakeService()
+	}
+
 	return AlertRuleService{
 		ruleStore:              store,
 		provenanceStore:        store,
