@@ -4,10 +4,13 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"sort"
 	"time"
 
 	"github.com/google/uuid"
 	"github.com/grafana/grafana-plugin-sdk-go/backend"
+	"github.com/grafana/grafana-plugin-sdk-go/backend/gtime"
+	"go.opentelemetry.io/otel"
 
 	"github.com/grafana/grafana/pkg/api/dtos"
 	"github.com/grafana/grafana/pkg/infra/log"
@@ -24,7 +27,6 @@ import (
 	"github.com/grafana/grafana/pkg/services/query"
 	"github.com/grafana/grafana/pkg/services/user"
 	"github.com/grafana/grafana/pkg/setting"
-	"github.com/grafana/grafana/pkg/tsdb/legacydata"
 	"github.com/grafana/grafana/pkg/util"
 )
 
@@ -45,6 +47,7 @@ type PublicDashboardServiceImpl struct {
 }
 
 var LogPrefix = "publicdashboards.service"
+var tracer = otel.Tracer("github.com/grafana/grafana/pkg/services/publicdashboards/service")
 
 // Gives us compile time error if the service does not adhere to the contract of
 // the interface
@@ -79,6 +82,9 @@ func ProvideService(
 }
 
 func (pd *PublicDashboardServiceImpl) GetPublicDashboardForView(ctx context.Context, accessToken string) (*dtos.DashboardFullWithMeta, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.GetPublicDashboardForView")
+	defer span.End()
+
 	pubdash, dash, err := pd.FindEnabledPublicDashboardAndDashboardByAccessToken(ctx, accessToken)
 	if err != nil {
 		return nil, err
@@ -110,10 +116,14 @@ func (pd *PublicDashboardServiceImpl) GetPublicDashboardForView(ctx context.Cont
 
 // FindByDashboardUid this method would be replaced by another implementation for Enterprise version
 func (pd *PublicDashboardServiceImpl) FindByDashboardUid(ctx context.Context, orgId int64, dashboardUid string) (*PublicDashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.FindByDashboardUid")
+	defer span.End()
 	return pd.serviceWrapper.FindByDashboardUid(ctx, orgId, dashboardUid)
 }
 
 func (pd *PublicDashboardServiceImpl) Find(ctx context.Context, uid string) (*PublicDashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.Find")
+	defer span.End()
 	pubdash, err := pd.store.Find(ctx, uid)
 	if err != nil {
 		return nil, ErrInternalServerError.Errorf("Find: failed to find public dashboard%w", err)
@@ -123,6 +133,8 @@ func (pd *PublicDashboardServiceImpl) Find(ctx context.Context, uid string) (*Pu
 
 // FindDashboard Gets a dashboard by Uid
 func (pd *PublicDashboardServiceImpl) FindDashboard(ctx context.Context, orgId int64, dashboardUid string) (*dashboards.Dashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.FindDashboard")
+	defer span.End()
 	dash, err := pd.dashboardService.GetDashboard(ctx, &dashboards.GetDashboardQuery{UID: dashboardUid, OrgID: orgId})
 	if err != nil {
 		var dashboardErr dashboards.DashboardErr
@@ -139,6 +151,8 @@ func (pd *PublicDashboardServiceImpl) FindDashboard(ctx context.Context, orgId i
 
 // FindByAccessToken Gets public dashboard by access token
 func (pd *PublicDashboardServiceImpl) FindByAccessToken(ctx context.Context, accessToken string) (*PublicDashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.FindByAccessToken")
+	defer span.End()
 	pubdash, err := pd.store.FindByAccessToken(ctx, accessToken)
 	if err != nil {
 		return nil, ErrInternalServerError.Errorf("FindByAccessToken: failed to find a public dashboard: %w", err)
@@ -153,6 +167,8 @@ func (pd *PublicDashboardServiceImpl) FindByAccessToken(ctx context.Context, acc
 
 // FindEnabledPublicDashboardAndDashboardByAccessToken Gets public dashboard and a dashboard by access token if public dashboard is enabled
 func (pd *PublicDashboardServiceImpl) FindEnabledPublicDashboardAndDashboardByAccessToken(ctx context.Context, accessToken string) (*PublicDashboard, *dashboards.Dashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.FindEnabledPublicDashboardAndDashboardByAccessToken")
+	defer span.End()
 	pubdash, dash, err := pd.FindPublicDashboardAndDashboardByAccessToken(ctx, accessToken)
 	if err != nil {
 		return pubdash, dash, err
@@ -171,6 +187,8 @@ func (pd *PublicDashboardServiceImpl) FindEnabledPublicDashboardAndDashboardByAc
 
 // FindPublicDashboardAndDashboardByAccessToken Gets public dashboard and a dashboard by access token
 func (pd *PublicDashboardServiceImpl) FindPublicDashboardAndDashboardByAccessToken(ctx context.Context, accessToken string) (*PublicDashboard, *dashboards.Dashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.FindPublicDashboardAndDashboardByAccessToken")
+	defer span.End()
 	pubdash, err := pd.FindByAccessToken(ctx, accessToken)
 	if err != nil {
 		return nil, nil, err
@@ -190,6 +208,8 @@ func (pd *PublicDashboardServiceImpl) FindPublicDashboardAndDashboardByAccessTok
 
 // Creates and validates the public dashboard and saves it to the database
 func (pd *PublicDashboardServiceImpl) Create(ctx context.Context, u *user.SignedInUser, dto *SavePublicDashboardDTO) (*PublicDashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.Create")
+	defer span.End()
 	// validate fields
 	err := validation.ValidatePublicDashboard(dto)
 	if err != nil {
@@ -247,6 +267,8 @@ func (pd *PublicDashboardServiceImpl) Create(ctx context.Context, u *user.Signed
 
 // Update: updates an existing public dashboard based on publicdashboard.Uid
 func (pd *PublicDashboardServiceImpl) Update(ctx context.Context, u *user.SignedInUser, dto *SavePublicDashboardDTO) (*PublicDashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.Update")
+	defer span.End()
 	// validate fields
 	err := validation.ValidatePublicDashboard(dto)
 	if err != nil {
@@ -303,6 +325,8 @@ func (pd *PublicDashboardServiceImpl) Update(ctx context.Context, u *user.Signed
 
 // NewPublicDashboardUid Generates a unique uid to create a public dashboard. Will make 3 attempts and fail if it cannot find an unused uid
 func (pd *PublicDashboardServiceImpl) NewPublicDashboardUid(ctx context.Context) (string, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.NewPublicDashboardUid")
+	defer span.End()
 	var uid string
 	for i := 0; i < 3; i++ {
 		uid = util.GenerateShortUID()
@@ -317,6 +341,8 @@ func (pd *PublicDashboardServiceImpl) NewPublicDashboardUid(ctx context.Context)
 
 // NewPublicDashboardAccessToken Generates a unique accessToken to create a public dashboard. Will make 3 attempts and fail if it cannot find an unused access token
 func (pd *PublicDashboardServiceImpl) NewPublicDashboardAccessToken(ctx context.Context) (string, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.NewPublicDashboardAccessToken")
+	defer span.End()
 	var accessToken string
 	for i := 0; i < 3; i++ {
 		var err error
@@ -335,12 +361,61 @@ func (pd *PublicDashboardServiceImpl) NewPublicDashboardAccessToken(ctx context.
 
 // FindAllWithPagination Returns a list of public dashboards by orgId, based on permissions and with pagination
 func (pd *PublicDashboardServiceImpl) FindAllWithPagination(ctx context.Context, query *PublicDashboardListQuery) (*PublicDashboardListResponseWithPagination, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.FindAllWithPagination")
+	defer span.End()
 	query.Offset = query.Limit * (query.Page - 1)
-	resp, err := pd.store.FindAllWithPagination(ctx, query)
+	resp, err := pd.store.FindAll(ctx, query)
 	if err != nil {
-		return nil, ErrInternalServerError.Errorf("FindAllWithPagination: %w", err)
+		return nil, ErrInternalServerError.Errorf("FindAllWithPagination: GetPublicDashboards: %w", err)
 	}
 
+	// join in the dashboard data
+	dashUIDs := make([]string, len(resp.PublicDashboards))
+	for i, pubdash := range resp.PublicDashboards {
+		dashUIDs[i] = pubdash.DashboardUid
+	}
+
+	dashboardsFound, err := pd.dashboardService.FindDashboards(ctx, &dashboards.FindPersistedDashboardsQuery{OrgId: query.OrgID, DashboardUIDs: dashUIDs, SignedInUser: query.User})
+	if err != nil {
+		return nil, ErrInternalServerError.Errorf("FindAllWithPagination: GetDashboards: %w", err)
+	}
+
+	dashMap := make(map[string]dashboards.DashboardSearchProjection)
+	for _, dash := range dashboardsFound {
+		dashMap[dash.UID] = dash
+	}
+
+	// add dashboard title & slug to response, and
+	// remove any public dashboards that don't have a corresponding active dashboard that the user has access to
+	idx := 0
+	for _, pubdash := range resp.PublicDashboards {
+		if dash, exists := dashMap[pubdash.DashboardUid]; exists {
+			pubdash.Title = dash.Title
+			pubdash.Slug = dash.Slug
+			resp.PublicDashboards[idx] = pubdash
+			idx++
+		} else {
+			resp.TotalCount--
+		}
+	}
+	resp.PublicDashboards = resp.PublicDashboards[:idx]
+
+	//  sort by title
+	sort.Slice(resp.PublicDashboards, func(i, j int) bool {
+		return resp.PublicDashboards[i].Title < resp.PublicDashboards[j].Title
+	})
+
+	// and now paginate
+	start := query.Offset
+	end := start + query.Limit
+	if start > len(resp.PublicDashboards) {
+		start = len(resp.PublicDashboards)
+	}
+	if end > len(resp.PublicDashboards) {
+		end = len(resp.PublicDashboards)
+	}
+	resp.PublicDashboards = resp.PublicDashboards[start:end]
+
 	resp.Page = query.Page
 	resp.PerPage = query.Limit
 
@@ -348,18 +423,26 @@ func (pd *PublicDashboardServiceImpl) FindAllWithPagination(ctx context.Context,
 }
 
 func (pd *PublicDashboardServiceImpl) ExistsEnabledByDashboardUid(ctx context.Context, dashboardUid string) (bool, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.ExistsEnabledByDashboardUid")
+	defer span.End()
 	return pd.store.ExistsEnabledByDashboardUid(ctx, dashboardUid)
 }
 
 func (pd *PublicDashboardServiceImpl) ExistsEnabledByAccessToken(ctx context.Context, accessToken string) (bool, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.ExistsEnabledByAccessToken")
+	defer span.End()
 	return pd.store.ExistsEnabledByAccessToken(ctx, accessToken)
 }
 
 func (pd *PublicDashboardServiceImpl) GetOrgIdByAccessToken(ctx context.Context, accessToken string) (int64, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.GetOrgIdByAccessToken")
+	defer span.End()
 	return pd.store.GetOrgIdByAccessToken(ctx, accessToken)
 }
 
 func (pd *PublicDashboardServiceImpl) Delete(ctx context.Context, uid string, dashboardUid string) error {
+	ctx, span := tracer.Start(ctx, "publicdashboards.Delete")
+	defer span.End()
 	// get existing public dashboard if exists
 	existingPubdash, err := pd.store.Find(ctx, uid)
 	if err != nil {
@@ -377,6 +460,8 @@ func (pd *PublicDashboardServiceImpl) Delete(ctx context.Context, uid string, da
 }
 
 func (pd *PublicDashboardServiceImpl) DeleteByDashboard(ctx context.Context, dashboard *dashboards.Dashboard) error {
+	ctx, span := tracer.Start(ctx, "publicdashboards.DeleteByDashboard")
+	defer span.End()
 	if dashboard.IsFolder {
 		// get all pubdashes for the folder
 		pubdashes, err := pd.store.FindByFolder(ctx, dashboard.OrgID, dashboard.UID)
@@ -420,7 +505,7 @@ func (pd *PublicDashboardServiceImpl) getSafeIntervalAndMaxDataPoints(reqDTO Pub
 	interval := time.Duration(reqDTO.IntervalMs) * time.Millisecond
 
 	// calculate a safe interval with time range from dashboard and safeResolution
-	dataTimeRange := legacydata.NewDataTimeRange(ts.From, ts.To)
+	dataTimeRange := gtime.NewTimeRange(ts.From, ts.To)
 	tr := backend.TimeRange{
 		From: dataTimeRange.GetFromAsTimeUTC(),
 		To:   dataTimeRange.GetToAsTimeUTC(),
@@ -464,6 +549,8 @@ func GenerateAccessToken() (string, error) {
 }
 
 func (pd *PublicDashboardServiceImpl) newCreatePublicDashboard(ctx context.Context, dto *SavePublicDashboardDTO) (*PublicDashboard, error) {
+	ctx, span := tracer.Start(ctx, "publicdashboards.newCreatePublicDashboard")
+	defer span.End()
 	//Check if uid already exists, if none then auto generate
 	var err error
 	uid := dto.PublicDashboard.Uid
