@@ -4,8 +4,7 @@ import (
 	"errors"
 	"time"
 
-	"github.com/grafana/grafana/pkg/services/auth/identity"
-	"github.com/grafana/grafana/pkg/services/dashboards/dashboardaccess"
+	"github.com/grafana/grafana/pkg/apimachinery/identity"
 	"github.com/grafana/grafana/pkg/services/search/model"
 )
 
@@ -55,8 +54,10 @@ type DeleteTeamCommand struct {
 }
 
 type GetTeamByIDQuery struct {
-	OrgID        int64
+	OrgID int64
+	// Get team by ID or UID. If ID is set, UID is ignored.
 	ID           int64
+	UID          string
 	SignedInUser identity.Requester
 	HiddenUsers  map[string]struct{}
 }
@@ -88,15 +89,29 @@ type SearchTeamsQuery struct {
 }
 
 type TeamDTO struct {
-	ID            int64                          `json:"id" xorm:"id"`
-	UID           string                         `json:"uid" xorm:"uid"`
-	OrgID         int64                          `json:"orgId" xorm:"org_id"`
-	Name          string                         `json:"name"`
-	Email         string                         `json:"email"`
-	AvatarURL     string                         `json:"avatarUrl"`
-	MemberCount   int64                          `json:"memberCount"`
-	Permission    dashboardaccess.PermissionType `json:"permission"`
-	AccessControl map[string]bool                `json:"accessControl"`
+	ID            int64           `json:"id" xorm:"id"`
+	UID           string          `json:"uid" xorm:"uid"`
+	OrgID         int64           `json:"orgId" xorm:"org_id"`
+	Name          string          `json:"name"`
+	Email         string          `json:"email"`
+	AvatarURL     string          `json:"avatarUrl"`
+	MemberCount   int64           `json:"memberCount"`
+	Permission    PermissionType  `json:"permission"`
+	AccessControl map[string]bool `json:"accessControl"`
+}
+
+type PermissionType int
+
+const (
+	PermissionTypeMember PermissionType = 0
+	PermissionTypeAdmin  PermissionType = 4
+)
+
+func (p PermissionType) String() string {
+	if p == PermissionTypeAdmin {
+		return "Admin"
+	}
+	return "Member"
 }
 
 type SearchTeamQueryResult struct {
@@ -113,7 +128,7 @@ type TeamMember struct {
 	TeamID     int64 `xorm:"team_id"`
 	UserID     int64 `xorm:"user_id"`
 	External   bool  // Signals that the membership has been created by an external systems, such as LDAP
-	Permission dashboardaccess.PermissionType
+	Permission PermissionType
 
 	Created time.Time
 	Updated time.Time
@@ -123,18 +138,17 @@ type TeamMember struct {
 // COMMANDS
 
 type AddTeamMemberCommand struct {
-	UserID     int64                          `json:"userId" binding:"Required"`
-	OrgID      int64                          `json:"-"`
-	TeamID     int64                          `json:"-"`
-	External   bool                           `json:"-"`
-	Permission dashboardaccess.PermissionType `json:"-"`
+	UserID     int64          `json:"userId" binding:"Required"`
+	Permission PermissionType `json:"-"`
 }
 
 type UpdateTeamMemberCommand struct {
-	UserID     int64                          `json:"-"`
-	OrgID      int64                          `json:"-"`
-	TeamID     int64                          `json:"-"`
-	Permission dashboardaccess.PermissionType `json:"permission"`
+	Permission PermissionType `json:"permission"`
+}
+
+type SetTeamMembershipsCommand struct {
+	Members []string `json:"members"`
+	Admins  []string `json:"admins"`
 }
 
 type RemoveTeamMemberCommand struct {
@@ -159,16 +173,16 @@ type GetTeamMembersQuery struct {
 // Projections and DTOs
 
 type TeamMemberDTO struct {
-	OrgID      int64                          `json:"orgId" xorm:"org_id"`
-	TeamID     int64                          `json:"teamId" xorm:"team_id"`
-	TeamUID    string                         `json:"teamUID" xorm:"uid"`
-	UserID     int64                          `json:"userId" xorm:"user_id"`
-	External   bool                           `json:"-"`
-	AuthModule string                         `json:"auth_module"`
-	Email      string                         `json:"email"`
-	Name       string                         `json:"name"`
-	Login      string                         `json:"login"`
-	AvatarURL  string                         `json:"avatarUrl" xorm:"avatar_url"`
-	Labels     []string                       `json:"labels"`
-	Permission dashboardaccess.PermissionType `json:"permission"`
+	OrgID      int64          `json:"orgId" xorm:"org_id"`
+	TeamID     int64          `json:"teamId" xorm:"team_id"`
+	TeamUID    string         `json:"teamUID" xorm:"uid"`
+	UserID     int64          `json:"userId" xorm:"user_id"`
+	External   bool           `json:"-"`
+	AuthModule string         `json:"auth_module"`
+	Email      string         `json:"email"`
+	Name       string         `json:"name"`
+	Login      string         `json:"login"`
+	AvatarURL  string         `json:"avatarUrl" xorm:"avatar_url"`
+	Labels     []string       `json:"labels"`
+	Permission PermissionType `json:"permission"`
 }
