@@ -5,6 +5,7 @@ import (
 	"context"
 	"encoding/json"
 	"errors"
+	"fmt"
 	"io"
 	"net/http"
 	"strings"
@@ -16,6 +17,7 @@ import (
 	"github.com/grafana/grafana-plugin-sdk-go/backend/httpclient"
 	"github.com/grafana/grafana-plugin-sdk-go/backend/instancemgmt"
 	"github.com/grafana/grafana-plugin-sdk-go/backend/log"
+	"github.com/grafana/grafana-plugin-sdk-go/experimental/featuretoggles"
 
 	"github.com/grafana/grafana/pkg/tsdb/azuremonitor/types"
 
@@ -44,6 +46,11 @@ var testRoutes = map[string]types.AzRoute{
 		Scopes:  []string{"https://api.loganalytics.io/.default"},
 		Headers: map[string]string{"x-ms-app": "Grafana", "Cache-Control": "public, max-age=60"},
 	},
+	traceExemplar: {
+		URL:     "https://api.loganalytics.io",
+		Scopes:  []string{"https://api.loganalytics.io/.default"},
+		Headers: map[string]string{"x-ms-app": "Grafana", "Cache-Control": "public, max-age=60"},
+	},
 	azurePortal: {
 		URL: "https://portal.azure.com",
 	},
@@ -53,9 +60,29 @@ func TestNewInstanceSettings(t *testing.T) {
 	tests := []struct {
 		name          string
 		settings      backend.DataSourceInstanceSettings
-		expectedModel types.DatasourceInfo
+		expectedModel *types.DatasourceInfo
 		Err           require.ErrorAssertionFunc
+		setupContext  func(ctx context.Context) context.Context
 	}{
+		{
+			name: "current user authentication disabled by feature toggle",
+			settings: backend.DataSourceInstanceSettings{
+				JSONData:                []byte(`{"azureAuthType":"currentuser"}`),
+				DecryptedSecureJSONData: map[string]string{},
+				ID:                      60,
+			},
+			expectedModel: nil,
+			Err: func(t require.TestingT, err error, _ ...interface{}) {
+				require.Error(t, err)
+				require.Contains(t, err.Error(), "current user authentication is not enabled for azure monitor")
+			},
+			setupContext: func(ctx context.Context) context.Context {
+				featureToggles := backend.NewGrafanaCfg(map[string]string{
+					featuretoggles.EnabledFeatures: "", // No enabled features
+				})
+				return backend.WithGrafanaConfig(ctx, featureToggles)
+			},
+		},
 		{
 			name: "creates an instance",
 			settings: backend.DataSourceInstanceSettings{
@@ -63,7 +90,7 @@ func TestNewInstanceSettings(t *testing.T) {
 				DecryptedSecureJSONData: map[string]string{"key": "value"},
 				ID:                      40,
 			},
-			expectedModel: types.DatasourceInfo{
+			expectedModel: &types.DatasourceInfo{
 				Credentials:             &azcredentials.AzureManagedIdentityCredentials{},
 				Settings:                types.AzureMonitorSettings{},
 				Routes:                  testRoutes,
@@ -81,7 +108,7 @@ func TestNewInstanceSettings(t *testing.T) {
 				DecryptedSecureJSONData: map[string]string{"clientSecret": "secret"},
 				ID:                      50,
 			},
-			expectedModel: types.DatasourceInfo{
+			expectedModel: &types.DatasourceInfo{
 				Credentials: &azcredentials.AzureClientSecretCredentials{
 					AzureCloud:   "AzureCustomizedCloud",
 					ClientSecret: "secret",
@@ -111,11 +138,23 @@ func TestNewInstanceSettings(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
+			ctx := context.Background()
+			if tt.setupContext != nil {
+				ctx = tt.setupContext(ctx)
+			}
+
 			factory := NewInstanceSettings(&httpclient.Provider{}, map[string]azDatasourceExecutor{}, log.DefaultLogger)
-			instance, err := factory(context.Background(), tt.settings)
+			instance, err := factory(ctx, tt.settings)
+
 			tt.Err(t, err)
-			if !cmp.Equal(instance, tt.expectedModel) {
-				t.Errorf("Unexpected instance: %v", cmp.Diff(instance, tt.expectedModel))
+
+			if tt.expectedModel == nil {
+				require.Nil(t, instance, "Expected instance to be nil")
+			} else {
+				require.NotNil(t, instance, "Expected instance to be created")
+				if !cmp.Equal(instance, *tt.expectedModel) {
+					t.Errorf("Unexpected instance: %v", cmp.Diff(instance, *tt.expectedModel))
+				}
 			}
 		})
 	}
@@ -149,7 +188,7 @@ func (f *fakeExecutor) ResourceRequest(rw http.ResponseWriter, req *http.Request
 	return nil, nil
 }
 
-func (f *fakeExecutor) ExecuteTimeSeriesQuery(ctx context.Context, originalQueries []backend.DataQuery, dsInfo types.DatasourceInfo, client *http.Client, url string) (*backend.QueryDataResponse, error) {
+func (f *fakeExecutor) ExecuteTimeSeriesQuery(ctx context.Context, originalQueries []backend.DataQuery, dsInfo types.DatasourceInfo, client *http.Client, url string, fromAlert bool) (*backend.QueryDataResponse, error) {
 	if client == nil {
 		f.t.Errorf("The HTTP client for %s is missing", f.queryType)
 	} else {
@@ -494,3 +533,146 @@ func TestCheckHealth(t *testing.T) {
 		})
 	}
 }
+
+func Test_QueryData(t *testing.T) {
+	tests := []struct {
+		name          string
+		queryType     string
+		expectedURL   string
+		Err           require.ErrorAssertionFunc
+		ExpectedError error
+	}{
+		{
+			name:          "Azure Monitor query type",
+			queryType:     azureMonitor,
+			expectedURL:   testRoutes[azureMonitor].URL,
+			Err:           require.NoError,
+			ExpectedError: nil,
+		},
+		{
+			name:          "Azure Log Analytics query type",
+			queryType:     azureLogAnalytics,
+			expectedURL:   testRoutes[azureLogAnalytics].URL,
+			Err:           require.NoError,
+			ExpectedError: nil,
+		},
+		{
+			name:          "Azure Resource Graph query type",
+			queryType:     azureResourceGraph,
+			expectedURL:   testRoutes[azureResourceGraph].URL,
+			Err:           require.NoError,
+			ExpectedError: nil,
+		},
+		{
+			name:          "Azure Traces query type",
+			queryType:     azureTraces,
+			expectedURL:   testRoutes[azureLogAnalytics].URL,
+			Err:           require.NoError,
+			ExpectedError: nil,
+		},
+		{
+			name:          "traceExemplar query type",
+			queryType:     traceExemplar,
+			expectedURL:   testRoutes[traceExemplar].URL,
+			Err:           require.NoError,
+			ExpectedError: nil,
+		},
+		{
+			name:          "Deprecated Application Insights query type",
+			queryType:     "Application Insights",
+			expectedURL:   "",
+			Err:           require.Error,
+			ExpectedError: fmt.Errorf("query type: '%s' is no longer supported. Please migrate this query (see https://grafana.com/docs/grafana/v9.0/datasources/azuremonitor/deprecated-application-insights/ for details)", "Application Insights"),
+		},
+		{
+			name:          "Deprecated Insights Analytics query type",
+			queryType:     "Insights Analytics",
+			expectedURL:   "",
+			Err:           require.Error,
+			ExpectedError: fmt.Errorf("query type: '%s' is no longer supported. Please migrate this query (see https://grafana.com/docs/grafana/v9.0/datasources/azuremonitor/deprecated-application-insights/ for details)", "Insights Analytics"),
+		},
+	}
+
+	service := &Service{
+		im: &fakeInstance{
+			routes: testRoutes,
+			services: map[string]types.DatasourceService{
+				azureMonitor: {
+					URL:        testRoutes[azureMonitor].URL,
+					HTTPClient: &http.Client{},
+				},
+				azureLogAnalytics: {
+					URL:        testRoutes[azureLogAnalytics].URL,
+					HTTPClient: &http.Client{},
+				},
+				azureResourceGraph: {
+					URL:        testRoutes[azureResourceGraph].URL,
+					HTTPClient: &http.Client{},
+				},
+				azureTraces: {
+					URL:        testRoutes[azureTraces].URL,
+					HTTPClient: &http.Client{},
+				},
+				traceExemplar: {
+					URL:        testRoutes[traceExemplar].URL,
+					HTTPClient: &http.Client{},
+				},
+			},
+		},
+		executors: map[string]azDatasourceExecutor{
+			azureMonitor: &fakeExecutor{
+				t:           t,
+				queryType:   azureMonitor,
+				expectedURL: testRoutes[azureMonitor].URL,
+			},
+			azureLogAnalytics: &fakeExecutor{
+				t:           t,
+				queryType:   azureMonitor,
+				expectedURL: testRoutes[azureLogAnalytics].URL,
+			},
+			azureResourceGraph: &fakeExecutor{
+				t:           t,
+				queryType:   azureMonitor,
+				expectedURL: testRoutes[azureResourceGraph].URL,
+			},
+			azureTraces: &fakeExecutor{
+				t:           t,
+				queryType:   azureMonitor,
+				expectedURL: testRoutes[azureTraces].URL,
+			},
+			traceExemplar: &fakeExecutor{
+				t:           t,
+				queryType:   azureMonitor,
+				expectedURL: testRoutes[traceExemplar].URL,
+			},
+		},
+	}
+	service.queryMux = service.newQueryMux()
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			res, _ := service.QueryData(context.Background(), &backend.QueryDataRequest{
+				PluginContext: backend.PluginContext{
+					DataSourceInstanceSettings: &backend.DataSourceInstanceSettings{
+						Name: "datasource_name",
+						UID:  "datasource_UID",
+					},
+				},
+				Queries: []backend.DataQuery{
+					{QueryType: tt.queryType,
+						RefID: "test"},
+				},
+			})
+
+			if res == nil {
+				t.Errorf("Expecting a response")
+			}
+
+			if res != nil {
+				tt.Err(t, res.Responses["test"].Error)
+				if tt.ExpectedError != nil {
+					assert.EqualError(t, res.Responses["test"].Error, tt.ExpectedError.Error())
+				}
+			}
+		})
+	}
+}
